==> kubernetes-model-autoscaling-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ContainerResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ContainerResourceMetricSourceFluent<A extends ContainerResourceMetricSourceFluent<A>> extends Fluent<A>{
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public ContainerResourceMetricSourceFluent.TargetNested<A> editTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<ContainerResourceMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ContainerResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ContainerResourceMetricSourceFluent<A extends ContainerResourceMetricSourceFluent<A>> extends Fluent<A>{
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public ContainerResourceMetricSourceFluent.TargetNested<A> editTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<ContainerResourceMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}
